@@ -1,6 +1,6 @@
 // module that does the conversion
 use bfom_lib::{
-    utilities::processing::{copy_css, file_find_markdown, uppercase_first_letter},
+    utilities::processing::{file_find_markdown, uppercase_first_letter},
     Converter,
 };
 
@@ -80,8 +80,7 @@ impl Controller {
         // get all teh files in teh specified folder
         let files = file_find_markdown(&self.src)?;
 
-        copy_files(&self.src, &self.dest, "css", &vec![&self.templates])?;
-        copy_files(&self.src, &self.dest, "html", &vec![&self.templates])?;
+        copy_files(&self.src, &self.dest, &["md"], &[&self.templates])?;
 
         //set up the converter
         let mut converter = Converter::new(self.html_void.clone(), self.indentation);
